<template>
  <!-- 参与人列表 -->
  <div class="right-panel" v-show="visible">
    <div class="right-panel-title">
      <span>参会人</span>
      <i class="icon icon-close" @click="close"></i>
    </div>
    <el-tabs v-model="rightPanelActiveName">
      <el-tab-pane :label="tabsLabelConnecting" name="1">
        <div class="room-member-list">
          <!-- 调度员 -->
          <div class="room-member-list-item">
            <div class="info">
              <el-avatar :size="40">
                <div class="avatar">{{ currentUserProfile.nick }}</div>
              </el-avatar>
              <div class="name">
                <span class="value">{{ currentUserProfile.nick }}（我）</span>
                <span class="tag">调度员</span>
              </div>
            </div>
            <div class="stream-controller">
              <!-- 禁用音频轨道 -->
              <i title="取消静音" v-if="isMutedAudio" class="btn btn-mute" @click="handleMuteAudio"></i>
              <!-- 启用音频轨道 -->
              <i title="静音" v-if="!isMutedAudio" class="btn btn-unmute" @click="handleMuteAudio"></i>
              <!-- 禁用视频轨道 -->
              <i
                title="开启视频"
                v-if="type === 'video' && yardmanType === '1' && isMutedVideo"
                class="btn btn-videoOn"
                @click="handleMuteVideo"
              ></i>
              <!-- 启用视频轨道 -->
              <i
                title="关闭视频"
                v-if="type === 'video' && yardmanType === '1' && !isMutedVideo"
                class="btn btn-videoOff"
                @click="handleMuteVideo"
              ></i>
            </div>
          </div>
          <!-- 被调度人 -->
          <div
            class="room-member-list-item"
            v-for="(item, index) in memberList.filter((x) => x.state !== 'DISCONNECTED')"
            :key="index"
          >
            <div class="info">
              <el-avatar :size="40">
                <div class="avatar">{{ item.nameSlice }}</div>
              </el-avatar>
              <div class="name">
                <span class="value">{{ item.name }}</span>
              </div>
            </div>
            <div class="stream-controller">
              <!-- 禁用音频轨道 -->
              <i title="静音" v-if="!item.isMutedAudio" class="btn btn-unmute" @click="memberMute(item.dispatchUid)"></i>
              <!-- 启用音频轨道 -->
              <i title="取消静音" v-if="item.isMutedAudio" class="btn btn-mute" @click="memberUnmute(item.dispatchUid)"></i>
              <!-- 举手 -->
              <i title="举手" v-if="item.handUp" class="btn btn-handup" @click="handup(item.dispatchUid)"></i>
              <!-- 移除成员 -->
              <i title="移除" class="btn btn-kick-out" @click="kickOut(item.dispatchUid)"></i>
            </div>
          </div>
        </div>
      </el-tab-pane>
      <el-tab-pane :label="tabsLabelDisconnecting" name="2">
        <div class="room-member-list">
          <div
            class="room-member-list-item"
            v-for="(item, index) in memberList.filter((x) => x.state === 'DISCONNECTED')"
            :key="index"
          >
            <div class="info">
              <el-avatar :size="40">
                <div class="avatar">{{ item.nameSlice }}</div>
              </el-avatar>
              <div class="name">
                <span class="value">{{ item.name }}</span>
              </div>
            </div>
            <div class="stream-controller">
              <span v-if="item.timeout" class="state-disconnected">未连上</span>
              <span v-if="item.beKickOut" class="state-disconnected">移除</span>
              <span v-if="!item.beKickOut && item.hangup" class="state-disconnected">已挂断</span>
              <!-- 重拨 -->
              <i class="btn btn-recall" @click="recall(item.dispatchUid)"></i>
            </div>
          </div>
        </div>
      </el-tab-pane>
    </el-tabs>
    <div class="right-panel-bottom">
      <el-row :gutter="20">
        <el-col :span="12">
          <div class="right-panel-bottom-btn" @click="muteAll">全员静音</div>
        </el-col>
        <el-col :span="12">
          <div class="right-panel-bottom-btn" @click="unMuteAll">解除全员静音</div>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-button class="right-panel-bottom-btn-full" type="primary" @click="showAddMember"> 添加成员 </el-button>
        </el-col>
      </el-row>
    </div>
  </div>
</template>

<script>
import { mapState } from "vuex";

export default {
  name: "participatedList",
  components: {},
  props: {
    visible: {
      type: Boolean,
      default: false,
    },
  },
  data() {
    return {
      rightPanelActiveName: "1",
    };
  },
  computed: {
    ...mapState({
      memberList: ({ gwsd }) => gwsd.memberList,
      currentUserProfile: ({ user }) => user.currentUserProfile,
      participant: ({ gwsd }) => gwsd.participant,
      yardmanType: ({ gwsd }) => gwsd.yardman.type,
      type: ({ gwsd }) => gwsd.yardman.callType,
      audio: ({ gwsd }) => gwsd.yardman.audio,
      video: ({ gwsd }) => gwsd.yardman.video,
      isMutedAudio: ({ gwsd }) => gwsd.yardman.isMutedAudio,
      isMutedVideo: ({ gwsd }) => gwsd.yardman.isMutedVideo,
    }),
    tabsLabelConnecting() {
      return `调度中（${this.memberList.filter((x) => x.state !== "DISCONNECTED").length}）`;
    },
    tabsLabelDisconnecting() {
      return `断联（${this.memberList.filter((x) => x.state === "DISCONNECTED").length}）`;
    },
  },
  watch: {},
  methods: {
    close() {
      this.$emit("update:visible", false);
    },
    handleMuteAudio() {
      this.$emit("muteAudio");
    },
    handleMuteVideo() {
      this.$emit("muteVideo");
    },
    memberMute(id) {
      console.log("memberMute", id);
      this.$emit("memberMute", id);
    },
    memberUnmute(id) {
      console.log("memberUnmute", id);
      this.$emit("memberUnmute", id);
    },
    kickOut(id) {
      this.$emit("kickOut", id);
    },
    handup(id) {
      this.$emit("handup", id);
    },
    recall(id) {
      this.$emit("recall", id);
    },
    showAddMember() {
      this.$emit("showAddMember");
    },
    muteAll() {
      this.$emit("muteAll");
    },
    unMuteAll() {
      this.$emit("unMuteAll");
    },
  },
  created() {},
  mounted() {},
};
</script>

<style lang="scss" scoped>
@import "~@/styles/rtc-client.scss";
</style>
